==> gbs.A.01.04.tar.gz: gbs.A.01.04/env/src/h/lock_level.h <==
/**********************************************************************
 
	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/


#ifndef ___LOCK_H___

#define LL_BLOCK	(-30)
#define LL_SLEEP_WAKEUP	(-20)	/* (-10) */
#define LL_TASK		(-10)	/* (-20) */

#define LL_TICK		4	/* 30 */

#define LL_MD		5
#define LL_MEMORY	9

#define LL_QUEUE_GC	10
#define LL_QUEUE	11

#define LL_LAUNCH	12
#define LL_RESOLV	13
#define LL_UTILS	14	/* 30 */
#define LL_THREAD_AREA	15	/* 40 */
#define LL_NETUTILS	16
#define LL_P_RESOLV	17
#define LL_GIF		20

#define LL_XLoHTTP	43
#define LL_CHAIN	44
#define LL_STREAM_THREAD 45
#define LL_STREAM	50
#define LL_XoH		51	/* 42 */

#define LL_BL		55

#define LL_DF		60	/* for XL load */
#define LL_UNIT		70

#define LL_LEX		90
#define LL_PARSE	100
#define LL_ENV		110

#define LL_XL_FD	120
#define LL_PCC		130

#define LL_PROXY	180
#define LL_SERVERINFO	190
#define LL_XLI_LEX	200
#define LL_XL_FIFO	210
#define LL_XLI		220

#define LL_SESSION	250
#define LL_XL_LOCK	260

#define LL_SETAGENT	270

#define LL_OBJ_MEM	280

#define LL_CINDEX	290

#define LL_TREE_CACHE	300
#define LL_LUSTER	310
#define LL_RAW_IMAGE	320
#define LL_STYLE	330

#define LL_MAP		400
#define LL_HTMLDB	410
#define LL_HTTP		420

#define LL_MSEQUENCE	500

#define LL_LOAD_RES	510 /* 740 */


#define LL_LOAD_STRUCTURE_AS 520
#define LL_IRQ		530
#define LL_LOAD_STRUCTURE 535	/* 620 */
#define LL_WF		540
#define LL_BB		545
#define LL_INDICATE	550
#define LL_ONMAP	560

#define LL_OV_LOCK	610

#define LL_BW		690
#define LL_DRAW_MATRIX	700
#define LL_DRAW		710
#define LL_STATUS	720	/* gbview */
#define LL_RESOURCE	730
#define LL_CU		735

#define LL_VIEW_AGENT_SESSION	745

#define LL_INTERFACE_R	750	/* 335 */
#define LL_INTERFACE	760	/* 340 */
#define LL_INTERFACE_O	770	/* 345 */
#define LL_MPW		805	/* 850 */

#define LL_ACRP		810
#define LL_ACRP_QUE_LOCK 820
#define LL_ACRP_TASK	830
#define LL_TICK_QUE	840

#define LL_ROUTE_LOCK	860
#define LL_IC		870

#define LL_RADAR	880
#define LL_RADAR_QUERY	885
#define LL_LUMP		890
#define LL_PMD		900

#define LL_QUEUE_GC_HIGH 910
#define LL_QUEUE_HIGH	920

#endif

==> gbs.A.02.05.tar.gz: gbs.A.02.05/env/src/h/lock_level.h <==
/**********************************************************************
 
	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/


#ifndef ___LOCK_H___

#define LL_BLOCK	(-30)
#define LL_SLEEP_WAKEUP	(-20)	/* (-10) */
#define LL_TASK		(-10)	/* (-20) */

#define LL_TICK		4	/* 30 */

#define LL_MD		5
#define LL_MEMORY	9

#define LL_QUEUE_GC	10
#define LL_QUEUE	11

#define LL_LAUNCH	12
#define LL_RESOLV	13
#define LL_UTILS	14	/* 30 */
#define LL_THREAD_AREA	15	/* 40 */
#define LL_NETUTILS	16
#define LL_P_RESOLV	17
#define LL_GIF		20

#define LL_XLoHTTP	43
#define LL_CHAIN	44
#define LL_STREAM_THREAD 45
#define LL_STREAM	50
#define LL_XoH		51	/* 42 */

#define LL_BL		55

#define LL_DF		60	/* for XL load */
#define LL_UNIT		70

#define LL_LEX		90
#define LL_PARSE	100
#define LL_ENV		110

#define LL_XL_FD	120
#define LL_PCC		130

#define LL_PROXY	180
#define LL_SERVERINFO	190
#define LL_XLI_LEX	200
#define LL_XL_FIFO	210
#define LL_XLI		220

#define LL_SESSION	250
#define LL_XL_LOCK	260

#define LL_SETAGENT	270

#define LL_OBJ_MEM	280

#define LL_TREE_CACHE	300
#define LL_LUSTER	310
#define LL_RAW_IMAGE	320
#define LL_STYLE	330

#define LL_MAP		400
#define LL_HTMLDB	410
#define LL_HTTP		420

#define LL_MSEQUENCE	500

#define LL_LOAD_RES	510 /* 740 */


#define LL_LOAD_STRUCTURE_AS 520
#define LL_IRQ		530
#define LL_LOAD_STRUCTURE 535	/* 620 */
#define LL_WF		540
#define LL_BB		545
#define LL_INDICATE	550
#define LL_ONMAP	560

#define LL_OV_LOCK	610

#define LL_BW		690
#define LL_DRAW_MATRIX	700
#define LL_DRAW		710
#define LL_STATUS	720	/* gbview */
#define LL_RESOURCE	730
#define LL_CU		735

#define LL_VIEW_AGENT_SESSION	745

#define LL_INTERFACE_R	750	/* 335 */
#define LL_INTERFACE	760	/* 340 */
#define LL_INTERFACE_O	770	/* 345 */
#define LL_MPW		805	/* 850 */

#define LL_CINDEX	807	/* 290 */

#define LL_ACRP		810
#define LL_ACRP_QUE_LOCK 820
#define LL_ACRP_TASK	830
#define LL_TICK_QUE	840

#define LL_ROUTE_LOCK	860
#define LL_IC		870

#define LL_RADAR	880
#define LL_RADAR_QUERY	885
#define LL_LUMP		890
#define LL_PMD		900

#define LL_QUEUE_GC_HIGH 910
#define LL_QUEUE_HIGH	920

#endif
